@@ -7,11 +7,15 @@ from trytond.pyson import Eval
 __all__ = ['PurchaseLine']
 
 
-class PurchaseLine:
-    __metaclass__ = PoolMeta
+class PurchaseLine(metaclass=PoolMeta):
     __name__ = 'purchase.line'
 
     work = fields.Many2One('project.work', 'Work Effort', select=True,
         domain=[
             ('company', '=', Eval('_parent_purchase', {}).get('company', -1)),
-            ])
+            ],
+        states={
+            'invisible': Eval('type') != 'line',
+            },
+        depends=['type'],
+        help="Add to the cost of the work effort.")
